# AutoBr

A bot to control web browser actions

## Installation
```pip
pip install autobr
```

Download ChromeDriver [here](https://chromedriver.chromium.org/downloads) according to your computer's Chrome version.

## License
The `AutoBr` project is provided by [Donghua Chen](https://github.com/dhchenx). 

